MCD cluster_NN1
Réservation ( num résa, arrhes, date résa, #num voilier u1, #num semaine u1, tarif )

- Le champ num résa constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Réservation.
- Les champs arrhes et date résa étaient déjà de simples attributs de l'entité Réservation.
- Le champ num voilier est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle Offrir à partir de l'entité Voilier en perdant son caractère identifiant. Il obéit en outre à la contrainte d'unicité 1.
- Le champ num semaine est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle Offrir à partir de l'entité Semaine en perdant son caractère identifiant. Il obéit en outre à la contrainte d'unicité 1.
- Le champ tarif a migré à partir de l'association de dépendance fonctionnelle Offrir.

Semaine ( num semaine, date début u1 )

- Le champ num semaine constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Semaine.
- Le champ date début était déjà un simple attribut de l'entité Semaine. Il obéit à la contrainte d'unicité 1.

Voilier ( num voilier, longueur )

- Le champ num voilier constitue la clé primaire de la table. C'était déjà un identifiant de l'entité Voilier.
- Le champ longueur était déjà un simple attribut de l'entité Voilier.